pub fn validate_cql(input: &str) -> Result<ValidatedCql, CqlError>Expand description
Validate a CQL string. Returns the parsed-fields decomposition on success or the first error encountered.
pub fn validate_cql(input: &str) -> Result<ValidatedCql, CqlError>Validate a CQL string. Returns the parsed-fields decomposition on success or the first error encountered.